@@ -7,8 +7,10 @@ OC.L10N.register(
     "Loading contacts …" : "Cargando contautos....",
     "Loading …" : "Cargando...",
     "Download" : "Baxar",
+    "Send email" : "Unviar mensaxe",
     "Groups" : "Grupos",
     "Group name" : "Nome del grupu",
+    "Circles" : "Círculos",
     "Rename" : "Renomar",
     "Enabled" : "Habilitar",
     "Delete" : "Desaniciar",
@@ -18,18 +20,32 @@ OC.L10N.register(
     "First name" : "Nome",
     "Last name" : "Apellíu",
     "Display name" : "Nome",
+    "Password protection" : "Password protection",
+    "Save" : "Guardar",
+    "Description" : "Descripción",
     "Invalid image" : "Imaxe non válida",
     "Name" : "Nome",
     "Title" : "Títulu",
     "Cancel" : "Encaboxar",
     "Address book" : "Llibreta de direiciones",
     "New contact" : "Contautu nuevu",
+    "Search contacts …" : "Guetar contautos...",
     "No results" : "Ensin resultaos",
+    "Personal circle" : "Círculu personal",
+    "Pending" : "Pendiente",
     "Close" : "Zarrar",
     "Import" : "Importar",
     "Not grouped" : "Nun s'agrupó",
+    "Circle" : "Círculu",
+    "User" : "Usuariu",
+    "Group" : "Group",
     "Email" : "Corréu",
     "Contact" : "Contautu",
+    "Member" : "Miembru",
+    "Moderator" : "Llendador",
+    "Admin" : "Almin",
+    "Owner" : "Owner",
+    "Users" : "Usuarios",
     "Nickname" : "Nomatu",
     "Detailed name" : "Nome detalláu",
     "Additional names" : "Nomes adicionales",
