@@ -4,20 +4,30 @@ OC.L10N.register(
     "Details" : "Detallar",
     "Contacts" : "Əlaqələr",
     "Download" : "Yüklə",
+    "Send email" : "Email yolla",
     "Groups" : "Qruplar",
     "Rename" : "Adı dəyiş",
     "Enabled" : "İşə salınıb",
     "Delete" : "Sil",
     "Copy link" : "linki nüsxələ",
     "can edit" : "dəyişmək olar",
+    "Password protection" : "Password protection",
+    "Save" : "Saxla",
+    "Description" : "Açıqlanma",
     "Invalid image" : "Yalnış şəkil",
     "Name" : "Ad",
     "Title" : "Başlıq",
     "Cancel" : "Dayandır",
+    "Pending" : "Gözləmə",
     "Close" : "Bağla",
     "Import" : "Əlavə et",
     "Not grouped" : "Qruplaşdırılmayıb",
+    "User" : "User",
+    "Group" : "Qrup",
     "Email" : "Email",
+    "Admin" : "İnzibatçı",
+    "Owner" : "Owner",
+    "Users" : "İstifadəçilər",
     "Notes" : "Qeydlər",
     "Location" : "Yerləşdiyiniz ünvan",
     "Home" : "Ev",
