@@ -6,12 +6,20 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Delete" : "حذف کریں",
     "can edit" : "تبدیل کر سکے ھیں",
+    "Password protection" : "Password protection",
+    "Save" : "حفظ",
+    "Description" : "تصریح",
     "Invalid image" : "غلط تصویر",
     "Name" : "اسم",
     "Title" : "عنوان",
     "Cancel" : "منسوخ کریں",
     "Close" : "بند ",
+    "User" : "User",
+    "Group" : "Group",
     "Email" : "email",
+    "Admin" : "ایڈمن",
+    "Owner" : "Owner",
+    "Users" : "صارفین",
     "Notes" : "Notes",
     "Location" : "مقام",
     "Work" : "کام",
