@@ -8,7 +8,7 @@ OC.L10N.register(
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的用戶界面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們沒有無謂地重複開發！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
     "Copy to full name" : "複製到全名",
     "Omit year" : "省略年份",
-    "Allow updating avatars from social media" : "允許從社群媒體更新大頭照",
+    "Allow updating avatars from social media" : "允許從社群媒體更新虛擬化身大頭照",
     "Please select a circle" : "請選擇社交圈子",
     "Loading circle …" : "社交圈子加載中 ...",
     "Your request to join this circle is pending approval" : "您加入此圈子的請求正在等待批准",
@@ -31,6 +31,7 @@ OC.L10N.register(
     "Group name" : "群組名稱",
     "Circles" : "社交圈子",
     "Create a new circle" : "創建新社交圈子",
+    "Contacts settings" : " 通訊錄設定",
     "Show all groups" : "顯示所有群組",
     "Collapse groups" : "收合群組",
     "Show all circles" : "顯示所有社交圈子",
@@ -70,13 +71,15 @@ OC.L10N.register(
     "Display name" : "顯示名稱",
     "Last modified" : "上次修改",
     "Sort by {sorting}" : "按 {sorting} 排序",
-    "Update avatars from social media" : "從社群媒體更新大頭照",
+    "Update avatars from social media" : "從社群媒體更新虛擬化身大頭照",
     "(refreshed once per week)" : "（每週重新整理一次）",
     "Address books" : "通訊錄",
+    "Manages" : "管理",
+    "Oversees" : "監督",
     "An error happened during the config change" : "配置更改期間發生錯誤",
     "Password protection" : "密碼保護",
     "Enforce password protection on files shared to this circle" : "對分享到此圈子的檔案實施密碼保護",
-    "Use a unique password for all shares to this circles" : "對此圈子的所有分享使用獨一無二的密碼",
+    "Use a unique password for all shares to this circle" : "對此圈子的所有分享使用獨一無二的密碼",
     "Unique password …" : "獨一無二的密碼 ...",
     "Save" : "保存",
     "Change unique password" : "更改獨一無二的密碼",
@@ -98,11 +101,11 @@ OC.L10N.register(
     "Delete picture" : "刪除圖片",
     "Invalid image" : "圖像無效",
     "Image is too big (max 1MB)." : "圖像過大（最大 1MB）。",
-    "Pick an avatar" : "選擇一個大頭照",
+    "Pick an avatar" : "選擇一個虛擬化身大頭照",
     "Error while processing the picture." : "處理相片時錯誤。",
-    "Avatar downloaded from social network" : "從社群網路下載大頭照",
-    "Avatar already up to date" : "大頭照已是最新",
-    "Avatar download failed" : "大頭照下載失敗",
+    "Avatar downloaded from social network" : "從社群網路下載虛擬化身大頭照",
+    "Avatar already up to date" : "虛擬化身大頭照已是最新",
+    "Avatar download failed" : "虛擬化身大頭照下載失敗",
     "No contact selected" : "未選擇聯絡人",
     "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
     "Name" : "姓名",
@@ -121,7 +124,7 @@ OC.L10N.register(
     "Address book" : "通訊錄",
     "New contact" : "新聯絡人",
     "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
-    "The contact doesn't exists anymore on the server." : "聯絡人不再存在於伺服器上。",
+    "The contact does not exists on the server anymore." : "伺服器上不再存在該聯絡人。",
     "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
     "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
     "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
@@ -160,6 +163,8 @@ OC.L10N.register(
     "Could not delete the member {displayName}" : "不能刪除成員 {displayName}",
     "Could not change the member level to {level}" : "無法將成員級別更改為 {level}",
     "Could not accept membership request" : "無法接受成為成員的申請",
+    "Chart" : "圖表",
+    "Select chart …" : "選擇圖表 ...",
     "Select type" : "選擇類型",
     "Select Date" : "選擇日期",
     "Add contact in group" : "新增聯絡人到群組",
@@ -187,6 +192,7 @@ OC.L10N.register(
     "Could not copy link to the clipboard." : "無法複製連結至剪貼板",
     "Not grouped" : "未歸類",
     "Recently contacted" : "最近聯絡",
+    "Organization chart" : "機構圖表",
     "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "社交圈子允許您在 Nextcloud 實例上與其他用戶創建群組並與他們分享。",
     "Circle" : "社交圈子",
     "User" : "用戶",
@@ -242,6 +248,7 @@ OC.L10N.register(
     "Voice" : "語音",
     "Car" : "車子",
     "Work pager" : "傳呼機（業務）",
+    "Manager" : "上司",
     "Social network" : "社交網絡",
     "Relationship to you" : "與您的關係",
     "Spouse" : "配偶",
@@ -254,7 +261,6 @@ OC.L10N.register(
     "Relative" : "親屬",
     "Friend" : "朋友",
     "Colleague" : "同事",
-    "Manager" : "上司",
     "Assistant" : "助理",
     "Related contacts" : "相關聯絡人",
     "Agent" : "代理人",
